[ ![Documentation](https://img.shields.io/badge/sphinx-documentation-informational.svg)](https://openqtsim.readthedocs.io)
[ ![License: MIT](https://img.shields.io/badge/License-MIT-informational.svg)](https://github.com/TUDelft-CITG/OpenQTSim/blob/master/LICENSE.txt)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3706929.svg)](https://doi.org/10.5281/zenodo.3706929)

[![CircleCI](https://circleci.com/gh/TUDelft-CITG/OpenQTSim.svg?style=svg&circle-token=fe7b8b4d1c30d69ef17df79ebd9e81c3e4823b7e)](https://circleci.com/gh/TUDelft-CITG/OpenQTSim)


# OpenQTSim

**Open** source **Q**ueueing **T**heory **Sim**ulation - Simulation package that facilitates discrete event simulation of queues with a Kendall notation.

Documentation can be found [here](https://openqtsim.readthedocs.io).

## Installation

To install OpenQTSim, run this command in your terminal:

``` bash
pip install openqtsim
```

This is the preferred method to install OpenQTSim, as it will always install the most recent stable release.

If you don not have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

You can read the [documentation](https://openqtsim.readthedocs.io/en/latest/installation.html) for other installation methods.

## Examples

The benefit of OpenQTSim is the generic set-up. This set-up allows the simulation of a range of queues with a Kendall notation. A number of examples are presented in a seperate [Jupyter Notebook repository](https://github.com/TUDelft-CITG/OpenQTSim-Notebooks). Information on how to use the notebooks is presented in that repository as well.
